import React from 'react';
import type { StoryObj, Meta } from '@storybook/react';
import { NsButton } from './';
import { ShoppingCart } from '@mui/icons-material';
import { withCenterDecorator } from '@/stories/decorators/withCenterDecorator';

type ComponentType = typeof NsButton;
type Story = StoryObj<ComponentType>;
type MetaStory = Meta<ComponentType>;

export default {
    title: 'Components/Inputs/NsButton',
    component: NsButton,
    decorators: [withCenterDecorator],
    argTypes: {
        children: {
            control: 'text',
            name: 'Children/Content',
            defaultValue: 'Button',
        },
        color: { name: 'Color Variants' },
        disabled: { control: 'boolean' },
        fullWidth: { control: 'boolean' },
        
        iconOnly: { control: 'hide' },
    },
    args: {
        children: 'Button',
        color: 'primary',
        size: 'medium',
        disabled: false,
        variant: 'contained',
        fullWidth: false,
        startIcon: '',
        endIcon: '',
    },
} as MetaStory;

export const button: Story = {};

export const IconOnlyButton: Story = {
    render: (args) => (
        <NsButton {...args} iconOnly darkModeEnabled={false}>
            <ShoppingCart />
        </NsButton>
    ),

    argTypes: {
        children: {
            control: 'hide',
        },
        color: { name: 'Color Variants' },
        disabled: { control: 'boolean' },
        fullWidth: { control: 'hide' },
        size: { control: 'hide' },
        iconOnly: { control: 'hide' },
    },
};
export const ButtonWithIcon: Story = {
    render: (args) => (
        <NsButton {...args} darkModeEnabled={false} startIcon={<ShoppingCart />}>
            
            Add to Cart
        </NsButton>
    ),
    argTypes: {
        children: {
            control: 'hide',
        },
        color: { name: 'Color Variants' },
        disabled: { control: 'boolean' },
        fullWidth: { control: 'boolean' },
        iconOnly: { control: 'hide' },
    },
};

